package org.dummy.tests

import scala.concurrent.duration._

import io.gatling.core.Predef._
import io.gatling.http.Predef._
import io.gatling.jdbc.Predef._


// Note : add the following jar file to your classpath : 
// https://github.com/Dynatrace/Dynatrace-Server-REST-Java-SDK/releases/download/v0.0.2/server-rest-sdk-0.0.2.jar
import com.dynatrace.sdk.server._, exceptions._, sessions._, sessions.models._, testautomation._, testautomation.models._, systemprofiles._, systemprofiles.models._



class LoadTest extends Simulation {
  
   
  
     // --------- Context ------------------

val dt_server_host = "localhost" // Server Hostname
val dt_server_port = 8021        // Server Port
val dt_ssl = true                // use SSL ?
val dt_user = "admin"            // User ID
val dt_pwd = "admin"             // User password
val dt_profile = "easyTravel"    // System Profile


   // --------- Initialization ------------------

// get a client configuration object
  val dc = new DynatraceClient(new BasicServerConfiguration(dt_user, dt_pwd, dt_ssl, dt_server_host, dt_server_port, false, 0))

  
 // get a SystemProfiles object from the client configuration to be able to interact with System Profiles (e.g. switch configurations)
  val sp = new SystemProfiles(dc)
  
  // initialize the context for recording a session with our test run
  val srr = new StartRecordingRequest(dt_profile)
  srr.setPresentableName("presentableName")   // User-readable presentable name for the session to be stored.
  srr.setDescription("description")           // Description for the session to be stored
  srr.setRecordingOption(RecordingOption.ALL) //   ALL : All PurePaths including time series,
                                              //   VIOLATIONS : Only PurePaths marked as violated, including time series.
                                              //   TIME_SERIES : Time series only.
  srr.setSessionLocked(false)                 // true to lock the session that is recorded, otherwise false
  srr.setTimestampAllowed(true)               // true to append timestamp information to the recorded session name, otherwise false

  
// get a Sessions object from the client configuration for the given parameters
  val s = new Sessions(dc)
 
  
  
  
  
 before { 
  
  
 // Optional: switch to a specific configuration,
    // to allow for specific details level in captured data
    // Note: make sure you created such configuration in AppMon before using it.
sp.activateProfileConfiguration(dt_profile, "verboseConfig")



  
  // start session recording for this test with given parameters
  s.startRecording(srr)


 }
  
  
  
  
  
  

	val httpProtocol = http
		.baseURL("http://localhost:8080")
		.inferHtmlResources()
		.acceptHeader("application/json, text/javascript, */*; q=0.01")
		.acceptEncodingHeader("gzip, deflate, sdch")
		.acceptLanguageHeader("fr-FR,fr;q=0.8,en-US;q=0.6,en;q=0.4")
		.userAgentHeader("Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/58.0.3029.110 Safari/537.36")



	val scn = scenario("LoadTest")
		.exec(http("Home")
			.get("/")
      .headers(dt_load_tag("Home page")))



	setUp(scn.inject(rampUsers(100) over(60 seconds))).protocols(httpProtocol)
	
	
	
	after {

    // stop AppMon session recording for this test  
      s.stopRecording(dt_profile)

   
    // switch back to default AppMon configuration  
    sp.activateProfileConfiguration(dt_profile, "Default") 
	}
	
	
	
  def dt_load_tag(
              NA:String
            , PC:String=""
            , VU:String=""
            , ID:String=""
            , GR:String=""
            , AN:String=""
            , SN:String=""
            , TE:String=""
            )
  : Map[String, String] =
  {
    
       /*  Load test attributes for request header :
        *  
NA     The timer NAme of the request.
               This can be the timer or transaction name used in the load test script to identify the response time measure, 
               or the document/page title, or any other human-readable URL encoded identifier for that document.
             NA=<timername>     
             Required
PC     The Page Context contains information about what document in the currently processed page is loaded.
              The following syntax is recommended, though not required:
              - If it is a named frame, then the value starts with the frame name.
              - The document number, unique for the page, is appended after a period.
              If embedded documents are cached, this number need not be progressive.
               PC=<FrameName>.<DocId>          
             optional
VU     The unique number of the Virtual User that sends the request.
             VU=<Id>     
             optional
ID     The unique request ID (serial number).
               This string should be unique for one web request or a set of web requests that together make up a step/transaction execution.
             ID=<Id>     
             optional
SI     The Source ID can be used to identify the product that triggered the request:
               For example WLT (Web Load Testing), SYM  (dynaTrace Synthetic Monitoring), BB (Backbone), or LM (Last Mile).   
           optional
GR     Geographic Region, useful only for the Synthetic Monitoring solution.
             This contains arbitrary text.    
             optional
AN     Agent Name: the logical name of the Agent from which the request originated.
             This information is used by Synthetic Monitoring.    
             optional
SN     Script Name.
               This groups a set of requests that make up a multi-step transaction, for example making an online purchase.
             optional
TE     TEst Name is the name of the entire load test.
             It uniquely identifies a test run.     
             optional
*/
    
      var value:String = "NA="+NA+";VU="+VU+";PC="+PC+";ID="+PC+";SI=Gatling;GR="+GR+";AN="+AN+";SN="+SN+";TE="+TE
     
      return Map("x-dynaTrace" -> value)
   }

	

}