package org.dummy.tests

import scala.concurrent.duration._

import io.gatling.core.Predef._
import io.gatling.http.Predef._
import io.gatling.jdbc.Predef._

// Note : add the following jar file to your classpath : 
// https://github.com/Dynatrace/Dynatrace-Server-REST-Java-SDK/releases/download/v0.0.2/server-rest-sdk-0.0.2.jar
import com.dynatrace.sdk.server._, exceptions._, sessions._, sessions.models._, testautomation._, testautomation.models._, systemprofiles._, systemprofiles.models._



class WebAPITest extends Simulation {
  
   
  
     // --------- Context ------------------

val dt_server_host = "localhost" // Server Hostname
val dt_server_port = 8021        // Server Port
val dt_ssl = true                // use SSL ?
val dt_user = "admin"            // User ID
val dt_pwd = "admin"             // User password
val dt_profile = "easyTravel"    // System Profile


   // --------- Initialization ------------------

// get a client configuration object
  val dc = new DynatraceClient(new BasicServerConfiguration(dt_user, dt_pwd, dt_ssl, dt_server_host, dt_server_port, false, 0))

  // initialize the context for our Test Run
  val ctrr = new CreateTestRunRequest()
  ctrr.setSystemProfile(dt_profile)      // System Profile.
  ctrr.setCategory(TestCategory.WEB_API) // Category of the test. Valid value is one of UNIT, UI_DRIVEN, PERFORMANCE, WEB_API or EXTERNAL.
  ctrr.setVersionMajor("1")              // Major version.
  ctrr.setVersionMinor("0")              // Minor version.
  ctrr.setVersionRevision("0")           // Revision.
  ctrr.setVersionBuild("1")              // Build number.
  ctrr.setVersionMilestone("1")          // Milestone.
  ctrr.setMarker("1.0.0.1.1")            // Special version marker, used in the heat-field of the Test Results dashlet chart.
  ctrr.setPlatform("Linux")              // The platform the test runs on. If not defined here, the platform is detected by the library.

  // Register the Test run and get the ID
  val dt_testrunid = new TestAutomation(dc).createTestRun(ctrr).getId()  
 
  
  
  
  
  
  
  
  

	val httpProtocol = http
		.baseURL("http://localhost:8080")
		.inferHtmlResources()
		.acceptHeader("application/json, text/javascript, */*; q=0.01")
		.acceptEncodingHeader("gzip, deflate, sdch")
		.acceptLanguageHeader("fr-FR,fr;q=0.8,en-US;q=0.6,en;q=0.4")
		.userAgentHeader("Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/58.0.3029.110 Safari/537.36")



	val scn = scenario("WebAPITest")
		.exec(http("findJourneys")
			.get("/services/JourneyService/findJourneys?destination=New%20York&fromDate=1406282400000&toDate=1437818400000")
      .headers(dt_web_api_tag("findJourneys", dt_testrunid)))


	setUp(scn.inject(atOnceUsers(1))).protocols(httpProtocol)
	
	
	
	
	
	
	
	
	 	  def dt_web_api_tag(TN:String, TR:String) : Map[String, String] =
  {
       /*  Web API test attributes for request header :

TN	Test Name (TN) should be provided using this field. 
		Metrics for requests with the same name are aggregated. 
		You can execute as many tests as desired within the same test run, 
		but give them different names if they are not testing the same thing.	
		
TR	TestRunId (TR), from a registered test run. 
		See REST API POST testruns for more information.	
		* */

      var value:String = "TN="+TN+";TR="+TR
     
      return Map("x-dynaTrace" -> value)
   }

	

}